@@ -13,4 +13,4 @@ from ._nelder_mead import NelderMead
 from ._parameter_sweep import ParameterSweep
 from ._particle_swarm import ParticleSwarm
 
-__all__ = ['base', 'Bisection', 'NelderMead', 'ParameterSweep', 'Convergence', 'ParticleSwarm']
+__all__ = ["base", "Bisection", "NelderMead", "ParameterSweep", "Convergence", "ParticleSwarm"]
