@@ -14,13 +14,14 @@ from ..helpers import get_nested_result
 from ._result_mapping import Result
 from .base import OptimizationEngineImpl, OptimizationEngineWrapper
 
-__all__ = ['Bisection']
+__all__ = ["Bisection"]
 
 
 class _BisectionImpl(OptimizationEngineImpl):
     """
     Implementation class for the bisection optimization engine.
     """
+
     def __init__(
         self,
         *,
@@ -32,9 +33,9 @@ class _BisectionImpl(OptimizationEngineImpl):
         target_value: float,
         logger: ty.Any,
         result_state: ty.Optional[ty.Dict[int, Result]] = None,
-        initialized: bool = False
+        initialized: bool = False,
     ):
-        super(_BisectionImpl, self).__init__(logger=logger, result_state=result_state)
+        super().__init__(logger=logger, result_state=result_state)
         self.lower = lower
         self.upper = upper
         self.initialized = initialized
@@ -48,7 +49,7 @@ class _BisectionImpl(OptimizationEngineImpl):
 
     @property
     def _state(self) -> ty.Dict[str, ty.Any]:
-        return {k: v for k, v in self.__dict__.items() if k not in ['_result_mapping', '_logger']}
+        return {k: v for k, v in self.__dict__.items() if k not in ["_result_mapping", "_logger"]}
 
     @property
     def is_finished(self) -> bool:
@@ -56,14 +57,14 @@ class _BisectionImpl(OptimizationEngineImpl):
 
     @property
     def average(self) -> float:
-        return (self.upper + self.lower) / 2.
+        return (self.upper + self.lower) / 2.0
 
     def _create_inputs(self) -> ty.List[ty.Dict[str, orm.Float]]:
         if not self.initialized:
-            return [{in_key: orm.Float(self.lower)
-                     for in_key in self.input_key},
-                    {in_key: orm.Float(self.upper)
-                     for in_key in self.input_key}]
+            return [
+                {in_key: orm.Float(self.lower) for in_key in self.input_key},
+                {in_key: orm.Float(self.upper) for in_key in self.input_key},
+            ]
         return [{in_key: orm.Float(self.average) for in_key in self.input_key}]
 
     def _update(self, outputs: ty.Dict[int, ty.Any]) -> None:
@@ -73,23 +74,20 @@ class _BisectionImpl(OptimizationEngineImpl):
             self.initialized = True
             assert num_vals == 2
             # initial step: change upper such that the _result_ of upper is higher
-            results = [get_nested_result(val, self.result_key) for val in output_values]
+            results = ty.cast(
+                ty.Sequence[ty.Union[orm.Int, orm.Float]],
+                [get_nested_result(val, self.result_key) for val in output_values],
+            )
             lower_val, upper_val = results
             if lower_val > upper_val:
                 self.lower, self.upper = self.upper, self.lower
-            if min(results) > self.target_value:
+            if min(results) > self.target_value or max(results) < self.target_value:
                 # TODO: add exit code
-                raise ValueError(
-                    "Target value '{}' is outside range '{}'".format(self.target_value, results)
-                )
-            if max(results) < self.target_value:
-                # TODO: add exit code
-                raise ValueError(
-                    "Target value '{}' is outside range '{}'".format(self.target_value, results)
-                )
+                raise ValueError(f"Target value '{self.target_value}' is outside range '{results}'")
         else:
             assert num_vals == 1
             res = get_nested_result(next(iter(output_values)), self.result_key)
+            res = ty.cast(ty.Union[orm.Int, orm.Float], res)
             if (res - self.target_value) > 0:
                 self.upper = self.average
             else:
@@ -101,13 +99,17 @@ class _BisectionImpl(OptimizationEngineImpl):
         """
         output_values = {
             key: get_nested_result(value.output, self.result_key)
-            for key, value in self._result_mapping.items()
+            for key, value in ty.cast(
+                # .items() is exposed dynamically via '_result_mapping.__getattr__'
+                ty.Tuple[int, ty.Any],
+                self._result_mapping.items(),
+            )
         }
         opt_index, opt_output = min(
-            output_values.items(), key=lambda item: abs(item[1].value - self.target_value)
+            output_values.items(), key=lambda item: abs(item[1].value - self.target_value)  # type: ignore
         )
         opt_input = self._result_mapping[opt_index].input[self.input_key[0]]
-        return (opt_index, opt_input, opt_output)
+        return (opt_index, opt_input, opt_output)  # type: ignore
 
 
 class Bisection(OptimizationEngineWrapper):
@@ -141,10 +143,10 @@ class Bisection(OptimizationEngineWrapper):
         upper: float,
         *,
         tol: float = 1e-6,
-        input_key: str = 'x',
-        result_key: str = 'result',
-        target_value: float = 0.,
-        logger: ty.Optional[ty.Any] = None
+        input_key: str = "x",
+        result_key: str = "result",
+        target_value: float = 0.0,
+        logger: ty.Optional[ty.Any] = None,
     ) -> _BisectionImpl:
         return cls._IMPL_CLASS(  # pylint: disable=no-member
             lower=lower,
@@ -153,5 +155,5 @@ class Bisection(OptimizationEngineWrapper):
             input_key=input_key,
             result_key=result_key,
             target_value=target_value,
-            logger=logger
+            logger=logger,
         )
